@@ -18,7 +18,6 @@
 
 #include <bakery/App/App_WithDoc.h>
 #include <bakery/App/Dialog_OfferSave.h>
-#include <bakery/App/Dialog_OverwriteFile.h>
 #include <gconfmm.h>
 #include <libgnomevfsmm.h>
 #include <libintl.h>
@@ -195,6 +194,32 @@ void App_WithDoc::offer_saveas()
   on_menu_file_saveas();
 }
 
+bool App_WithDoc::file_exists(const Glib::ustring& uri)
+{
+  //Check whether file exists already:
+  {
+    // Try to open the input file.
+    Gnome::Vfs::Handle read_handle;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+    {
+      read_handle.open(uri, Gnome::Vfs::OPEN_READ);
+
+      //It does (there was no exception):
+      return true;
+    }
+    catch(const Gnome::Vfs::exception& /* ex */)
+    {
+      return false; //It does not exist.
+    }
+#else
+      std::auto_ptr<Gnome::Vfs::exception> error;
+      read_handle.open(uri, Gnome::Vfs::OPEN_READ, error);
+      if(error.get() != NULL) return false;
+#endif
+  }
+}
+
 void App_WithDoc::on_menu_file_saveas()
 {
   //Display File Save dialog and respond to choice:
@@ -214,26 +239,6 @@ void App_WithDoc::on_menu_file_saveas()
 
     bool bUseThisFileUri = true;
 
-    //Check whether file exists already:
-    {
-      // Try to open the input file.
-      Gnome::Vfs::Handle read_handle;
-      try
-      {
-        read_handle.open(file_uri, Gnome::Vfs::OPEN_READ);
-
-        //It does (there was no exception), so ask the user to confirm overwrite:
-        const bool bOverwrite = true; //The FileChooser aksed already. ui_ask_overwrite(file_uri);
-
-        //Respond to button that was clicked:
-        bUseThisFileUri = bOverwrite;
-      }
-      catch(const Gnome::Vfs::exception& ex)
-      {
-        bUseThisFileUri = true; //It does not exist.
-      }
-    }
-
     //Save to this filepath:
     if(bUseThisFileUri)
     {
@@ -284,8 +289,8 @@ void App_WithDoc::on_menu_file_save()
       if(bTest)
       {
         //Disable Save and SaveAs menu items:
-        after_successful_save();    
-   
+        after_successful_save();
+
         //Close the document if this save was in response to a 'Do you want to save before closing?':
         //if(m_bCloseAfterSave) // || m_bExiting
         //  close_mark_or_destroy();
