@@ -173,6 +173,7 @@ bool Document::read_from_disk()
   // open the input file for read access
   Gnome::Vfs::Handle read_handle;
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     read_handle.open(m_file_uri, Gnome::Vfs::OPEN_READ);
@@ -182,18 +183,30 @@ bool Document::read_from_disk()
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
   }
+#else
+  std::auto_ptr<Gnome::Vfs::exception> error;
+  read_handle.open(m_file_uri, Gnome::Vfs::OPEN_READ, error);
+  if(error.get() != NULL) return false; //print_error(ex, input_uri_string);
+#endif
 
   // Read data from the input uri:
   guint buffer[BYTES_TO_PROCESS] = {0, }; // For each chunk.
   Gnome::Vfs::FileSize bytes_read = 0;
   std::string data; //We use a std::string because we might not get whole UTF8 characters at a time. This might not be necessary.
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
+#endif
   {
     bool bContinue = true;
     while(bContinue)
     {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
       bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS);
+#else
+      bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS, error);
+      if(error.get() != NULL) break;
+#endif
 
       if(bytes_read == 0)
         bContinue = false; //stop because we reached the end.
@@ -204,8 +217,14 @@ bool Document::read_from_disk()
       }
     }
   }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Gnome::Vfs::exception& ex)
   {
+#else
+  if(error.get() != NULL)
+  {
+    Gnome::Vfs::exception& ex = *error.get();
+#endif
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
   }
@@ -228,6 +247,7 @@ bool Document::write_to_disk()
 
     Gnome::Vfs::Handle write_handle;
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       //0660 means "this user and his group can read and write this non-executable file".
@@ -236,10 +256,18 @@ bool Document::write_to_disk()
     }
     catch(const Gnome::Vfs::exception& ex)
     {
+#else
+    std::auto_ptr<Gnome::Vfs::exception> error;
+    write_handle.create(m_file_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* loading zero means octal */, error);
+    if(error.get() != NULL)
+    {
+      const Gnome::Vfs::exception& ex = *error.get();
+#endif
      // If the operation was not successful, print the error and abort
      return false; // print_error(ex, output_uri_string);
     }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       //Write the data to the output uri
@@ -247,6 +275,12 @@ bool Document::write_to_disk()
     }
     catch(const Gnome::Vfs::exception& ex)
     {
+#else
+    GnomeVFSFileSize bytes_written = write_handle.write(m_strContents.data(), m_strContents.bytes(), error);
+    if(error.get() != NULL)
+    {
+      Gnome::Vfs::exception& ex = *error.get();
+#endif
       // If the operation was not successful, print the error and abort
       return false; //print_error(ex, output_uri_string);
     }
@@ -313,16 +347,25 @@ bool Document::get_read_only() const
       return false; //It must be a default empty document, not yet saved, so it is not read-only.
     else
     {
+      Glib::RefPtr<Gnome::Vfs::FileInfo> info;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
       try
       {
-        Gnome::Vfs::FilePermissions permissions = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS)->get_permissions();
-        const bool read_only = ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) != Gnome::Vfs::PERM_ACCESS_WRITABLE);
-        return read_only;
+        info = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS);
       }
       catch(const Gnome::Vfs::exception& ex)
       {
         return false; //We should at least be able to read the permissions, so maybe the location is invalid. I'm not sure what the best return result here is.
       }
+#else
+      std::auto_ptr<Gnome::Vfs::exception> error;
+      info = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS, error);
+      if(error.get() != NULL) return false;
+#endif
+
+      Gnome::Vfs::FilePermissions permissions = info->get_permissions();
+      const bool read_only = ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) != Gnome::Vfs::PERM_ACCESS_WRITABLE);
+      return read_only;
     }
   }
 
